@@ -1,7 +1,7 @@
+from collections.abc import Generator
 from pathlib import Path
 from shutil import rmtree
 from tempfile import mkdtemp
-from typing import Generator
 
 import pytest
 
